@@ -5,6 +5,7 @@
 #####################################
 
 ## Version 2011/09/28
+## Version 2011/12/11
 
 ##############################################
 ## Function to find missing data patterns   ##
@@ -106,7 +107,7 @@ rsem.ssq<-function(x){
 ## Function rsem.emmusig                    ##
 ##############################################
 
-rsem.emmusig<-function(x, misinfo, varphi=.1, max_it=1000, st='i'){
+rsem.emmusig<-function(x, misinfo, varphi=.1, max.it=1000, st='i'){
 ## x: data set
 ## misinfo: missing data pattern
 ## varphi: 
@@ -136,7 +137,7 @@ rsem.emmusig<-function(x, misinfo, varphi=.1, max_it=1000, st='i'){
 		ck<-sqrt(chip)
 		cbeta<-( p*pchisq(chip, p+2) + chip*(1-prob) )/p
 	}
-	while (dt>ep && n_it <= max_it){
+	while (dt>ep && n_it <= max.it){
 		sumx<-rep(0,p); sumxx<-array(0,dim=c(p,p)); sumw1<-0; sumw2<-0;
 		npat<-dim(misinfo)[1]  ## number of missing data patterns
 		p1<-misinfo[1,2]       ## number of observed variables in pattern 1
@@ -262,7 +263,7 @@ rsem.emmusig<-function(x, misinfo, varphi=.1, max_it=1000, st='i'){
 		sig0<-sig1;
 		n_it<-n_it+1;
 	} ## end while
-	list(mu=mu1, sigma=sig1, max_it=n_it)
+	list(mu=mu1, sigma=sig1, max.it=n_it)
 }
 
 ##############################################
@@ -312,8 +313,8 @@ rsem.index<-function(p,oj){
 ##   selected variables                     ##
 ## Function rsem.indexv                     ##
 ##############################################
-rsem.indexv<-function(p, V_forana){
-	pv<-length(V_forana)
+rsem.indexv<-function(p, select){
+	pv<-length(select)
 	pvs<-pv*(pv+1)/2
 	index_s<-rep(0,pvs)
 	count<-p
@@ -323,7 +324,7 @@ rsem.indexv<-function(p, V_forana){
 			count<-count+1
 			for (iv in 1:pv){
 				for (jv in iv:pv){
-					if (i==V_forana[iv] && j==V_forana[jv]){
+					if (i==select[iv] && j==select[jv]){
 						countv<-countv+1
 						index_s[countv]<-count
 					}
@@ -331,7 +332,7 @@ rsem.indexv<-function(p, V_forana){
 			}
 		}
 	}
-	c(V_forana, index_s)
+	c(select, index_s)
 }
 
 ##############################################
@@ -339,8 +340,8 @@ rsem.indexv<-function(p, V_forana){
 ##   selected variables                     ##
 ## Function rsem.indexvc                    ##
 ##############################################
-rsem.indexvc<-function(p, V_forana){
-	pv<-length(V_forana)
+rsem.indexvc<-function(p, select){
+	pv<-length(select)
 	pvs<-pv*(pv+1)/2
 	index_s<-rep(0,pvs)
 	count<-0
@@ -350,7 +351,7 @@ rsem.indexvc<-function(p, V_forana){
 			count<-count+1
 			for (iv in 1:pv){
 				for (jv in iv:pv){
-					if (i==V_forana[iv] && j==V_forana[jv]){
+					if (i==select[iv] && j==select[jv]){
 						countv<-countv+1
 						index_s[countv]<-count
 					}
@@ -606,9 +607,9 @@ rsem.Ascov<-function(x, mu0, sig0, misinfo, varphi=.1){
 ## Main function for batch analysis         ##
 ## rsem.main                                ## 
 ##############################################
-rsem<-function(dset, V_forana, EQSmodel, moment=TRUE, varphi=.1, st='i', max_it=1000, eqsdata='data.txt', eqsweight='weight.txt', EQSpgm="C:/Progra~1/EQS61/WINEQS.EXE", serial="1234"){
+rsem<-function(dset, select, EQSmodel, moment=TRUE, varphi=.1, st='i', max.it=1000, eqsdata='data.txt', eqsweight='weight.txt', EQSpgm="C:/Progra~1/EQS61/WINEQS.EXE", serial="1234"){
 ## data: data matrix
-## V_forana: variabes to be selected for analysis in EQS
+## select: variabes to be selected for analysis in EQS
 ## varphi: proportion of data to be downweighted
 ## miss: missing data indicator
 	if (missing(dset)) stop("A data set is needed!")
@@ -618,10 +619,10 @@ rsem<-function(dset, V_forana, EQSmodel, moment=TRUE, varphi=.1, st='i', max_it=
 	cat("Sample size n =", n, "\n")
 	cat("Total number of variables q =", p, "\n\n")
 	
-	if (missing(V_forana)) V_forana<-c(1:p)	
-	cat("The following",length(V_forana),"variables are selected for SEM models \n")
-	cat(colnames(dset)[V_forana], "\n\n")
-	p_v<-length(V_forana)
+	if (missing(select)) select<-c(1:p)	
+	cat("The following",length(select),"variables are selected for SEM models \n")
+	cat(colnames(dset)[select], "\n\n")
+	p_v<-length(select)
 	
 	pvs<-p_v+p_v*(p_v+1)/2
 	
@@ -635,8 +636,8 @@ rsem<-function(dset, V_forana, EQSmodel, moment=TRUE, varphi=.1, st='i', max_it=
 	print(misinfo)
 	cat("\n")
 ## run EM
-	em_results<-rsem.emmusig(x,misinfo,varphi, max_it, st)
-	if (em_results$max_it >= max_it){ warning("\nMaximum iteration for EM is exceeded and the results may not be trusted. Change max_it to a greater number.\n") }
+	em_results<-rsem.emmusig(x,misinfo,varphi, max.it, st)
+	if (em_results$max.it >= max.it){ warning("\nMaximum iteration for EM is exceeded and the results may not be trusted. Change max.it to a greater number.\n") }
 	hmu1<-em_results$mu                           ## means for all variables including auxiliary variables
 	hsigma1<-em_results$sigma                     ## covariance matrix for all variables
 ## Calculate the sandwitch covariance matrix
@@ -644,14 +645,14 @@ rsem<-function(dset, V_forana, EQSmodel, moment=TRUE, varphi=.1, st='i', max_it=
 	Abeta<-ascov_results$Abeta
 	Bbeta<-ascov_results$Bbeta
 	hupsilon<-ascov_results$Gamma
-	index_beta<-rsem.indexv(p, V_forana)
-	index_sig<-rsem.indexvc(p,V_forana)
+	index_beta<-rsem.indexv(p, select)
+	index_sig<-rsem.indexvc(p,select)
 	
-	index_other<-c(V_forana, index_sig)
+	index_other<-c(select, index_sig)
 	gamma_other<-hupsilon[index_other,index_other]
 	
-	hmu<-hmu1[V_forana]                           ## means for selected variables
-	hsigma<-hsigma1[V_forana, V_forana]           ## covariance matrix for selected variables
+	hmu<-hmu1[select]                           ## means for selected variables
+	hsigma<-hsigma1[select, select]           ## covariance matrix for selected variables
 	cat("Estimated means: \n")
 	print(hmu)
 	if (missing(EQSmodel)){
@@ -661,8 +662,8 @@ rsem<-function(dset, V_forana, EQSmodel, moment=TRUE, varphi=.1, st='i', max_it=
 		se.matrix.hsig1<-array(0, c(p,p))
 		se.matrix.hsig1[lower.tri(se.matrix.hsig1,TRUE)]<-se.hsig1
 		se.matrix.hsig1[upper.tri(se.matrix.hsig1)]<-se.matrix.hsig1[lower.tri(se.matrix.hsig1)]
-		se.hmu<-se.hmu1[V_forana]
-        se.matrix.hsig<-se.matrix.hsig1[V_forana,V_forana]
+		se.hmu<-se.hmu1[select]
+        se.matrix.hsig<-se.matrix.hsig1[select,select]
 		cat("Standard errors for estimated means:\n");
 		print(se.hmu)
 	}
@@ -710,8 +711,7 @@ rsem<-function(dset, V_forana, EQSmodel, moment=TRUE, varphi=.1, st='i', max_it=
 		fit<-res$fit.indices
 		pval<-res$pval
 		
-		fit.stat<-rbind(c(fit[sub(' +','',row.names(fit))=='CHI',1],
-		                pval[sub(' +','',row.names(pval))=='PVAL',1]),
+		fit.stat<-rbind(
 						c(fit[sub(' +','',row.names(fit))=='SBCHI',1], pval[sub(' +','',row.names(pval))=='SBPVAL',1]),
 						c(fit[sub(' +','',row.names(fit))=='MVADJCHI',1], pval[sub(' +','',row.names(pval))=='TPADJCHI',1]),
 						c(fit[sub(' +','',row.names(fit))=='YBRESTST',1], pval[sub(' +','',row.names(pval))=='TPYBRTST',1]),
@@ -719,15 +719,15 @@ rsem<-function(dset, V_forana, EQSmodel, moment=TRUE, varphi=.1, st='i', max_it=
 						)
 		
 		colnames(fit.stat)<-c('T','p')
-		rownames(fit.stat)<-c('NML','RML','AML','CRADF','RF')
+		rownames(fit.stat)<-c('RML','AML','CRADF','RF')
 		
 ## print fit statistics
-		cat('Fit statistics:\n')
+		cat('Test statistics:\n')
 		print(fit.stat)
 		cat('\nParameter estimates:\n')
 		z<-res$par.table[,1]/res$par.table[,3]
-		par.est<-cbind(res$par.table[,c(1:3)], z)
-		colnames(par.est)<-c('Parameter', 'NSE', 'SE', 'z-score')
+		par.est<-cbind(res$par.table[,c(1,3)], z)
+		colnames(par.est)<-c('Parameter', 'SE', 'z-score')
 		print(par.est)
 		invisible(list(fit.stat=fit.stat, para=par.est, sem=list(mu=hmu, sigma=hsigma, gamma_eqs_cov=hgamma_sig, gammam_eqs_mcov=hgamma_beta_eqs), misinfo=miss_pattern, em=em_results, ascov=ascov_results, eqs=res))
 	}else{
